<?php
/**
 * Footer settings
 * 
 * @package Style Mag
 * @since 1.0.0
 */

add_action( 'customize_register', 'style_mag_upsell_section_register', 10 );
/**
 * Add settings for upsell links
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function style_mag_upsell_section_register( $wp_customize ) {
	require get_template_directory() . '/inc/admin/customizer-upsell/upsell-section/upsell-button.php';
    require get_template_directory() . '/inc/admin/customizer-upsell/upsell-section/upsell-control.php';
    $wp_customize->register_section_type( 'Style_Mag_Upsell_Button' );
    $wp_customize->register_control_type( 'Style_Mag_Upsell_Control' );
    /**
     * Add Upsell Button
     * 
     */
    $wp_customize->add_section(
		new Style_Mag_Upsell_Button( $wp_customize, 
            'upsell_button', [
                'button_text'   => esc_html__( 'View Premium', 'style-mag' ),
                'button_url'    => esc_url( '//blazethemes.com/theme/style-mag-pro/' ),
                'priority'      => 1
            ]
        )
	);



     /**
     * Add premium features listing section
     * 
     */
    $wp_customize->add_section( 'homepage_info_section', array(
        'title' => esc_html__( 'HomePage Setup Info', 'style-mag' ),
        'priority'  => 1,
    ));


    /**
     * List out "features" settings
     * 
     */
    $wp_customize->add_setting( 'homepage_info_settings',
        array(
            'sanitize_callback' => 'wp_kses_post',
      )
    );

    $wp_customize->add_control( 
        new Style_Mag_Upsell_Control( $wp_customize, 'homepage_info_settings', array(
            'section'     => 'homepage_info_section',
            'description'   => esc_html__( "To Setup Homepage You Need to Install Elementor. Or purchase Style Mag Pro for Both Gutenberg Blocks And Elementor", "style-mag" ),
            'type'        => 'style-mag-upsell'
        )
    ));

      /**
     * Add premium features listing section
     * 
     */
    $wp_customize->add_section( 'upgrade_section', array(
        'title' => esc_html__( 'Premium Features', 'style-mag' ),
        'priority'  => 1,
    ));


    /**
     * List out "features" settings
     * 
     */
    $wp_customize->add_setting( 'upgrade_settings',
        array(
            'sanitize_callback' => 'wp_kses_post',
      )
    );

    $wp_customize->add_control( 
        new Style_Mag_Upsell_Control( $wp_customize, 'upgrade_settings', array(
            'section'     => 'upgrade_section',
            'description'   => esc_html__( "Upgrade To Pro", "style-mag" ),
            'type'        => 'style-mag-upsell',
            'features'    => array(
                esc_html__( 'Unlock more advanced features', 'style-mag' ),
                esc_html__( 'Easy One Demo Install', 'style-mag' ),
                esc_html__( 'Numerous Color Options', 'style-mag' ),
                esc_html__( 'Unlimited Social Icons', 'style-mag' ),
                esc_html__( 'In-built post views count filter', 'style-mag' ),
                esc_html__( 'Customize hyperlinks target', 'style-mag' ),
                esc_html__( 'Show/hide post elements ( For each blocks )', 'style-mag' ),
                esc_html__( 'Customize content length', 'style-mag' ),
                esc_html__( 'Customize category/tags count', 'style-mag' ),
                sprintf( '%1$1s & %2$1s', esc_html__( 'Gutenberg Blocks', 'style-mag' ), esc_html__( 'Elementor Widgets', 'style-mag' ) ),
                esc_html__( 'Multiple Header Layouts ( 2 )', 'style-mag' ),
                esc_html__( 'Menu Colors', 'style-mag' ),
                esc_html__( 'Menu Hover Colors', 'style-mag' ),
                esc_html__( 'Menu Hover Effects', 'style-mag' ),
                esc_html__( 'Image Hover Effects', 'style-mag' ),
                esc_html__( 'Fallback Image', 'style-mag' ),
                esc_html__( 'AJAX pagination and load more ( load posts without page reload )', 'style-mag' ),
                esc_html__( 'Breadcrumbs more settings', 'style-mag' ),
                esc_html__( 'Meta prefix text changable', 'style-mag' ),
                esc_html__( 'More ( post/archive/page/blog/home ) layouts ', 'style-mag' ),
                esc_html__( 'More ( post/archive/page/blog/home ) sidebar layouts', 'style-mag' ),
                esc_html__( 'Footer four column', 'style-mag' ),
                esc_html__( 'Style Settings ( colors, fonts, variants )', 'style-mag' ),
                esc_html__( 'Typography Settings ( font size, colors, font family, variants )', 'style-mag' ),
                esc_html__( '600+ google fonts', 'style-mag' ),
                sprintf( '%1$1s & %2$1s', esc_html__( 'Pagination in Blocks', 'style-mag' ), esc_html__( 'Widgets', 'style-mag' ) ),
                esc_html__( 'Optimized for Speed', 'style-mag' ),
                esc_html__( 'Fully Multilingual and Translation ready', 'style-mag' ),
                esc_html__( 'Unlimited Support', 'style-mag' ),
                sprintf( '& %1$1s', esc_html__( 'many more ....', 'style-mag' ) )
            ),
        ))
    );

    /**
     * Add Upsell Button
     * 
     */
    $wp_customize->add_section(
        new Style_Mag_Upsell_Button( $wp_customize, 
            'demo_import_button', array(
                'button_text'   => esc_html__( 'Go to Import', 'style-mag' ),
                'button_url'    => esc_url( admin_url('themes.php?page=style-mag-info.php') ),
                'title'         => esc_html__('Import Demo Data', 'style-mag'),
                'priority'  => 1000,
            )
        )
    );
}

/**
 * Enqueue theme upsell controls scripts
 * 
 */
function style_mag_upsell_scripts() {
    wp_enqueue_style( 'style-mag-upsell', get_template_directory_uri() . '/inc/admin/customizer-upsell/upsell-section/upsell.css', array(), '1.0.0', 'all' );
    wp_enqueue_script( 'style-mag-upsell', get_template_directory_uri() . '/inc/admin/customizer-upsell/upsell-section/upsell.js', array(), '1.0.0', 'all' );
}
add_action( 'customize_controls_enqueue_scripts', 'style_mag_upsell_scripts' );